==> haskell-wai-conduit-3.0.0.4-27-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-wai-conduit.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: wai-conduit
version: 3.0.0.4
id: wai-conduit-3.0.0.4-2GKKkjPbCK4KZTZbiV91eC
key: wai-conduit-3.0.0.4-2GKKkjPbCK4KZTZbiV91eC
license: MIT
maintainer: michael@snoyman.com
author: Michael Snoyman
homepage: https://github.com/yesodweb/wai
synopsis: conduit wrappers for WAI
description:
    API docs and the README are available at <http://www.stackage.org/package/wai-conduit>.
category: Web, Conduit
abi: ad4a4b072610eec0fb8e987aaf5d6bc0
exposed: True
exposed-modules:
    Network.Wai.Conduit
import-dirs: /usr/lib/ghc-8.4.3/site-local/wai-conduit-3.0.0.4
library-dirs: /usr/lib/ghc-8.4.3/site-local/wai-conduit-3.0.0.4
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/wai-conduit-3.0.0.4
hs-libraries: HSwai-conduit-3.0.0.4-2GKKkjPbCK4KZTZbiV91eC
depends:
    base-4.11.1.0 wai-3.2.1.2-2Zp08jZTTCf5NIL0VZMFx7
    conduit-1.3.0.2-VILpe2nHJJEI731JKcPDn transformers-0.5.5.0
    bytestring-0.10.8.2 http-types-0.12.1-9rf2Bc0mANC4pe1MDcYyOl
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             wai-3.2.1.2-2Zp08jZTTCf5NIL0VZMFx7=1b3b53b0d45a8d6668a7144a7e93d4f6
             conduit-1.3.0.2-VILpe2nHJJEI731JKcPDn=5128b3631ba5c225d63f54c8b3e56168
             transformers-0.5.5.0=4f41484af13f560f1d83ed79e1be4572
             bytestring-0.10.8.2=9faa89cf4769cbd12751f8644ca9e618
             http-types-0.12.1-9rf2Bc0mANC4pe1MDcYyOl=f077e3c0d9d6c05be2dfc7d9c3ae67ad
haddock-interfaces: /usr/share/doc/haskell-wai-conduit/html/wai-conduit.haddock
haddock-html: /usr/share/doc/haskell-wai-conduit/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-wai-conduit-3.0.0.4-28-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-wai-conduit.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: wai-conduit
version: 3.0.0.4
id: wai-conduit-3.0.0.4-5wSe0oXmBn5FCuFyIjbXrJ
key: wai-conduit-3.0.0.4-5wSe0oXmBn5FCuFyIjbXrJ
license: MIT
maintainer: michael@snoyman.com
author: Michael Snoyman
homepage: https://github.com/yesodweb/wai
synopsis: conduit wrappers for WAI
description:
    API docs and the README are available at <http://www.stackage.org/package/wai-conduit>.
category: Web, Conduit
abi: dd43bc4f453dcf5f8deebdd75e5b8d1f
exposed: True
exposed-modules:
    Network.Wai.Conduit
import-dirs: /usr/lib/ghc-8.4.3/site-local/wai-conduit-3.0.0.4
library-dirs: /usr/lib/ghc-8.4.3/site-local/wai-conduit-3.0.0.4
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/wai-conduit-3.0.0.4
hs-libraries: HSwai-conduit-3.0.0.4-5wSe0oXmBn5FCuFyIjbXrJ
depends:
    base-4.11.1.0 wai-3.2.1.2-2Zp08jZTTCf5NIL0VZMFx7
    conduit-1.3.0.3-x8g8aXTvFNBw0LirvXMm0 transformers-0.5.5.0
    bytestring-0.10.8.2 http-types-0.12.1-9rf2Bc0mANC4pe1MDcYyOl
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             wai-3.2.1.2-2Zp08jZTTCf5NIL0VZMFx7=1b3b53b0d45a8d6668a7144a7e93d4f6
             conduit-1.3.0.3-x8g8aXTvFNBw0LirvXMm0=51f7edcb96a33f6cb49639332e2e26cb
             transformers-0.5.5.0=4f41484af13f560f1d83ed79e1be4572
             bytestring-0.10.8.2=9faa89cf4769cbd12751f8644ca9e618
             http-types-0.12.1-9rf2Bc0mANC4pe1MDcYyOl=f077e3c0d9d6c05be2dfc7d9c3ae67ad
haddock-interfaces: /usr/share/doc/haskell-wai-conduit/html/wai-conduit.haddock
haddock-html: /usr/share/doc/haskell-wai-conduit/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
